local _, BigBrother = ...
local L = LibStub("AceLocale-3.0"):GetLocale("BigBrother")

local flaskBuffs = BigBrother.SpellData.flasks

local elixirBuffs = {}
for i,v in ipairs(BigBrother.SpellData.elixirsBattle) do elixirBuffs[i] = v end
for i,v in ipairs(BigBrother.SpellData.elixirsGuardian) do elixirBuffs[#elixirBuffs+1] = v end

local foodBuffs = BigBrother.SpellData.foods
local foodBuffsMax = BigBrother.SpellData.foodsMax

function BigBrother:ConsumableCheck(channel)
	local groups = self:GetCheckedGroups()
	local inRaid = IsInRaid()
	local index = 0

	local missingFlaskList = {}
	local missingElixirList = {}
	local missingFoodList = {}

	for unit in self:IterateGroup() do
		index = index + 1
		local name = UnitName(unit)
		if not name then break end

		local subgroup = inRaid and select(3, GetRaidRosterInfo(index)) or 1
		local online = UnitIsConnected(unit)
		local dead = UnitIsDeadOrGhost(unit)

		if online and not dead and groups[subgroup] then

			--check flasks/elixirs
			if self.db.profile.checkFlasks then
				local numElixirs = 0
				for _, spellName in next, elixirBuffs do
					if UnitBuff(name, spellName) then
						numElixirs = numElixirs + 1
					end
				end

				if numElixirs == 1 then
					missingElixirList[#missingElixirList + 1] = name
				elseif numElixirs == 0 then
					local found = nil
					for _, spellName in next, flaskBuffs do
						if UnitBuff(name, spellName) then
							found = true
							break
						end
					end
					if not found then
						missingFlaskList[#missingFlaskList + 1] = name
					end
				end
			end

			--check food
			if self.db.profile.checkFood then
				local found = nil
				for _, spellName in next, foodBuffs do
					local id = select(11, UnitBuff(name, spellName))
					if id and (not self.db.profile.maxOnly or foodBuffsMax[id]) then
						found = true
						break
					end
				end
				if not found then
					missingFoodList[#missingFoodList + 1] = name
				end
			end

		end --if
	end --for

	if #missingElixirList > 0 then
		self:SendChatMessageList(L["One Elixir"], missingElixirList, channel)
	end
	if #missingFlaskList > 0 then
		self:SendChatMessageList(L["No Flask"], missingFlaskList, channel)
	end
	if #missingFoodList > 0 then
		self:SendChatMessageList(L["Not Well Fed"], missingFoodList, channel)
	end
end
